# flake8-bandit

Automated security testing built into flake8.

## Getting Started

`pip install flake8-bandit`

This project is still in it's infancy! Please report any bugs you find or if it is not working in your code editor please let me know!
